1.0.0 API documentation: fast_square_root.hpp File Reference

| 1.0.0 API documentation

Functions
fast_square_root.hpp File Reference

GLM_GTX_fast_square_root More...

Go to the source code of this file.

## Functions
template<typename genType >
GLM_FUNC_DECL genType | fastDistance (genType x, genType y)
| Faster than the common distance function but less accurate. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL T | fastDistance (vec< L, T, Q > const &x, vec< L, T, Q > const &y)
| Faster than the common distance function but less accurate. More...
template<typename genType >
GLM_FUNC_DECL genType | fastInverseSqrt (genType x)
| Faster than the common inversesqrt function but less accurate. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | fastInverseSqrt (vec< L, T, Q > const &x)
| Faster than the common inversesqrt function but less accurate. More...
template<typename genType >
GLM_FUNC_DECL genType | fastLength (genType x)
| Faster than the common length function but less accurate. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL T | fastLength (vec< L, T, Q > const &x)
| Faster than the common length function but less accurate. More...
template<typename genType >
GLM_FUNC_DECL genType | fastNormalize (genType x)
| Faster than the common normalize function but less accurate. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | fastNormalize (vec< L, T, Q > const &x)
| Faster than the common normalize function but less accurate. More...
template<typename genType >
GLM_FUNC_DECL genType | fastSqrt (genType x)
| Faster than the common sqrt function but less accurate. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | fastSqrt (vec< L, T, Q > const &x)
| Faster than the common sqrt function but less accurate. More...

## Detailed Description

GLM_GTX_fast_square_root

See also
  Core features (dependence)

Definition in file fast_square_root.hpp.